<?php

namespace Drupal\proc\Ajax;

use Drupal\Core\Ajax\CommandInterface;

/**
 * Ajax Command to update the proc recipients currently selected.
 *
 * This command is the main way to signal the frontend that the list of
 * recipients was changed (by whatever means) and all encrypted content might
 * already require revalidation.
 */
class ProcUpdateRecipientsCommand implements CommandInterface {

  /**
   * The HTML for the threads to be inserted in the page.
   *
   * @var int[]
   *   Array of all the recipients in the list.
   */
  protected array $recipientIds;

  /**
   * The source (a field, or something else) where the data originated from.
   *
   * Sources should always send all their selected values. Providing a simple
   * way of ensuring the frontend has the correct complete array of information.
   *
   * @var string
   *   String identifier for the source of all the items.
   */
  protected string $source;

  /**
   * Constructs a list of all the recipients that are added to the proc.
   *
   * @param array $recipientIds
   *   All the recipients to be added to the protected content.
   *
   * @todo Currently these are userIds but this will update to keyring ids in
   *   future versions.
   */
  public function __construct(array $recipientIds, string $source) {
    $this->recipientIds = $recipientIds;
    $this->source = $source;
  }

  /**
   * {@inheritdoc}
   */
  public function render() {
    return [
      'command' => 'procUpdateRecipients',
      'recipients' => $this->recipientIds,
      'source' => $this->source,
    ];
  }

}
