<?php

namespace Drupal\proc\Plugin\Field\FieldWidget;

use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\WidgetBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;

/**
 * Defines a widget that listens to a window event.
 *
 * The proc module requires that you pass a list of different user id's, these
 * are then made into keys inside a modal so the file can be uploaded.
 *
 * @FieldWidget(
 *   id = "proc_listener_attachment",
 *   module = "proc",
 *   label = @Translation("Attached modal"),
 *   field_types = {
 *     "proc_entity_reference_field"
 *   }
 * )
 */
class FileAttachmentWidget extends WidgetBase {

  /**
   * {@inheritdoc}
   */
  public function formElement(FieldItemListInterface $items, $delta, array $element, array &$form, FormStateInterface $form_state) {
    return [
      'upload_link' => [
        '#title' => $this->t('Upload attachment'),
        '#type' => 'link',
        '#url' => Url::fromRoute('proc.encrypt.modal.file', ['query' => ['origin_field' => $items->getName() . '_' . $delta]]),
        '#attributes' => [
          'class' => ['use-ajax'],
          'data-proc-encrypt-link' => 'data-proc-encrypt-link',
          'data-dialog-type' => 'modal',
          'data-dialog-options' => json_encode([
            'width' => 1200,
          ]),
        ],
        '#attached' => [
          'library' => ['core/drupal.dialog.ajax'],
        ],
      ],
      'display' => [
        '#type' => 'textfield',
        '#title' => $this->t('Checking') . " " . $delta . " " . $items->getName(),
        '#attributes' => [
          'data-proc-origin-field' => $items->getName() . '_' . $delta,
        ],
      ],
    ];
  }

}
