<?php

namespace Drupal\proc;

use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\proc\Entity\KeyringStorageInterface;

/**
 * Handle checking of the fact a keychain.
 */
class ProcKeychain implements ProcKeychainInterface {

  /**
   * The keyring storage interface.
   *
   * @var \Drupal\proc\Entity\KeyringStorageInterface
   *   The keyring storage.
   */
  protected KeyringStorageInterface $keyringStorage;

  /**
   * Basic constructor.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entityTypeManager
   *   The entity type manager.
   */
  public function __construct(EntityTypeManagerInterface $entityTypeManager) {
    $this->keyringStorage = $entityTypeManager->getStorage('proc');
  }

  /**
   * {@inheritdoc}
   */
  public function hasKeyring(int $userId) : bool {
    $query = $this->keyringStorage->getQuery();
    $result = $query->accessCheck(FALSE)
      ->condition('user_id', $userId)
      ->condition('type', 'cipher', '!=')
      ->range(0, 1)
      ->execute();

    return !empty($result);
  }

}
